@@ -65,10 +65,12 @@ use App::Dochazka::REST::Model::Shared qw(
     priv_by_eid 
     schedule_by_eid 
     select_set_of_single_scalar_rows
+    split_tsrange
     timestamp_delta_plus
 );
 use App::Dochazka::REST::ResourceDefs;
 use App::Dochazka::REST::Shared qw( :ALL );  # all the shared_* functions
+use App::Dochazka::REST::Util::Holiday qw( holidays_in_daterange );
 use App::Dochazka::REST::Util::Schedule qw( intervals_in_schedule );
 use Data::Dumper;
 use Module::Runtime qw( use_module );
@@ -328,6 +330,55 @@ sub handler_forbidden {
 }
 
 
+=head3 handler_holiday_tsrange
+
+Handler for 'holiday/:tsrange' resource.
+
+=cut
+
+sub handler_holiday_tsrange {
+    my ( $self, $pass ) = @_;
+    $log->debug( "Entering " . __PACKAGE__ . "::handler_holiday_tsrange, pass number $pass" );
+    
+    # first pass
+    if ( $pass == 1 ) {
+        my $status = split_tsrange( 
+            $self->context->{'dbix_conn'},
+            $self->context->{'mapping'}->{'tsrange'},
+        );
+        if ( $status->not_ok ) {
+            $status->{'http_code'} = ( $status->code eq 'DOCHAZKA_DBI_ERR' )
+                ? 500 
+                : 400;
+            $self->mrest_declare_status( $status );
+            return 0;
+        }
+        my $datereg = qr/(\d+-\d+-\d+)/;
+        my ( $begin ) = $status->payload->[0] =~ $datereg;
+        my ( $end ) = $status->payload->[1] =~ $datereg;
+        if ( ! defined( $begin ) or ! defined( $end ) ) {
+            $self->mrest_declare_status( 
+                level => 'ERR', 
+                code => 400,
+                explanation => 'DISPATCH_UNBOUNDED_TSRANGE',
+            );
+            return 0;
+        }
+        $self->context->{'stashed_value'} = { 
+            "date_range" => { 
+                "begin" => $begin, 
+                "end" => $end,
+            }
+        };
+    }
+
+    # second pass
+    return $CELL->status_ok( 'DOCHAZKA_HOLIDAYS_IN_TSRANGE', payload =>
+        holidays_in_daterange( %{ $self->context->{'stashed_value'}->{'date_range'} } )
+    );
+}
+
+
 =head3 handler_param
 
 Handler for 'param/:type/:param' resource.
@@ -1708,19 +1759,10 @@ sub _handler_get_intlock {
         return 0 unless $emp;
 
         # determine the tsrange
-        my $mapping = $context->{'mapping'};
-        my ( $status, $tsr );
-        $tsr = $mapping->{'tsrange'} if $mapping->{'tsrange'};
-        if ( $mapping->{'ts'} and $mapping->{'psqlint'} ) {
-            $status = timestamp_delta_plus( 
-                $context->{'dbix_conn'}, 
-                $mapping->{'ts'}, 
-                $mapping->{'psqlint'} 
-            ); 
-            return $status unless $status->ok;
-            $tsr = "[ " . $mapping->{ts} . ", " . $status->payload . " )";
-        }
-            
+        my $status = _tsrange_from_context( $context );
+        return $status unless $status->ok;
+        my $tsr = $status->payload;
+
         my @ARGS = (
             $context->{'dbix_conn'},
             $emp->eid,
@@ -2635,4 +2677,32 @@ sub handler_delete_schedule_scode {
     return $context->{'stashed_schedule_object'}->delete( $context );
 }
 
+=head2 Helper functions
+
+=head3 _tsrange_from_mapping
+
+Given a mapping that contains C<ts> and C<psqlint> properties (i.e.
+a timestamp and a PostgreSQL interval), return a status object that,
+if the delta add operation is successful, will contain a proper 
+timestamp.
+
+=cut
+
+sub _tsrange_from_context { 
+    my $context = shift;
+    my $mapping = $context->{'mapping'};
+    my ( $status, $tsr );
+    $tsr = $mapping->{'tsrange'} if $mapping->{'tsrange'};
+    if ( $mapping->{'ts'} and $mapping->{'psqlint'} ) {
+        $status = timestamp_delta_plus( 
+            $context->{'dbix_conn'}, 
+            $mapping->{'ts'}, 
+            $mapping->{'psqlint'} 
+        ); 
+        return $status unless $status->ok;
+        $tsr = "[ " . $mapping->{ts} . ", " . $status->payload . " )";
+    }
+    return $CELL->status_ok( 'SUCCESS', payload => $tsr );
+}
+
 1;
